.. _general_documents:

============================
General documents
============================

.. toctree::
  :glob:
  :maxdepth: 1

  general_documents/project_approach
  general_documents/anomaly_detection
  general_documents/data_exploration
  general_documents/data_storage
  general_documents/production_platform
  general_documents/feature_extraction
  general_documents/weather_features
  general_documents/tsfresh